@@ -2,8 +2,7 @@
 
 from datetime import datetime
 from operator import itemgetter
-from urlparse import urlparse
-from urllib import unquote_plus
+import six
 from pyga import utils
 from pyga import exceptions
 
@@ -93,9 +92,10 @@ class Campaign(object):
         if not self.source:
             raise exceptions.ValidationError('Campaigns need to have at least the "source" attribute defined.')
 
-    def create_from_referrer(self, url):
+    @staticmethod
+    def create_from_referrer(url):
         obj = Campaign(Campaign.TYPE_REFERRAL)
-        parse_rslt = urlparse(url)
+        parse_rslt = six.moves.urllib.parse.urlparse(url)
         obj.source = parse_rslt.netloc
         obj.content = parse_rslt.path
         return obj
@@ -114,9 +114,9 @@ class Campaign(object):
             key, val = param.split('=')
 
             try:
-                setattr(self, self.UTMZ_PARAM_MAP[key], unquote_plus(val))
+                setattr(self, self.UTMZ_PARAM_MAP[key], six.moves.urllib.parse.unquote_plus(val))
             except KeyError:
-                pass
+                continue
 
         return self
 
@@ -180,7 +180,7 @@ class CustomVariable(object):
 class Event(object):
     '''
     Represents an Event
-    http://code.google.com/apis/analytics/docs/tracking/eventTrackerOverview.html
+    https://developers.google.com/analytics/devguides/collection/gajs/eventTrackerGuide
 
     Properties:
     category -- The general event category
@@ -415,14 +415,14 @@ class Visitor(object):
 
     def __setattr__(self, name, value):
         if name == 'unique_id':
-            if value and value < 0 or value > 0x7fffffff:
+            if value and (value < 0 or value > 0x7fffffff):
                 raise ValueError('Visitor unique ID has to be a 32-bit integer between 0 and 0x7fffffff')
         object.__setattr__(self, name, value)
 
     def __getattribute__(self, name):
         if name == 'unique_id':
             tmp = object.__getattribute__(self, name)
-            if tmp == None:
+            if tmp is None:
                 self.unique_id = self.generate_unique_id()
         return object.__getattribute__(self, name)
 
@@ -460,7 +460,7 @@ class Visitor(object):
             for key in ('HTTP_X_FORWARDED_FOR', 'REMOTE_ADDR'):
                 if key in meta and not ip:
                     ips = meta.get(key, '').split(',')
-                    ip = ips[len(ips) - 1].strip()
+                    ip = ips[-1].strip()
                     if not utils.is_valid_ip(ip):
                         ip = ''
                     if utils.is_private_ip(ip):
