@@ -5,12 +5,11 @@ import calendar
 from math import floor
 from pyga.entities import Campaign, CustomVariable, Event, Item, Page, Session, SocialInteraction, Transaction, Visitor
 import pyga.utils as utils
-import urllib
-import urllib2
+import six
 
 __author__ = "Arun KR (kra3) <the1.arun@gmail.com>"
 __license__ = "Simplified BSD"
-__version__ = '2.4.2'
+__version__ = '2.5.1'
 
 logger = logging.getLogger(__name__)
 
@@ -43,7 +42,7 @@ class GIFRequest(object):
 
     def build_http_request(self):
         params = self.build_parameters()
-        query_string = urllib.urlencode(params.get_parameters())
+        query_string = six.moves.urllib.parse.urlencode(params.get_parameters())
         query_string = query_string.replace('+', '%20')
 
         # Mimic Javascript's encodeURIComponent() encoding for the query
@@ -73,7 +72,7 @@ class GIFRequest(object):
         logger.debug(url)
         if post:
             logger.debug(post)
-        return urllib2.Request(url, post, headers)
+        return six.moves.urllib.request.Request(url, post, headers)
 
     def build_parameters(self):
         '''Marker implementation'''
@@ -85,7 +84,7 @@ class GIFRequest(object):
 
         #  Do not actually send the request if endpoint host is set to null
         if self.config.endpoint:
-            response = urllib2.urlopen(
+            response = six.moves.urllib.request.urlopen(
                 request, timeout=self.config.request_timeout)
 
         return response
@@ -154,6 +153,14 @@ class Request(GIFRequest):
         '''
         params.utmip = self.visitor.ip_address
         params.aip = self.tracker.config.anonimize_ip_address and 1 or None
+
+        # Add override User-Agent parameter (&ua) and override IP address
+        # parameter (&uip). Note that the override IP address parameter is
+        # always anonymized, as if &aip were present (see
+        # https://developers.google.com/analytics/devguides/collection/protocol/v1/parameters#uip)
+        params.ua = self.visitor.user_agent
+        params.uip = utils.anonymize_ip(self.visitor.ip_address)
+
         if params.aip:
             # If anonimization of ip enabled? then!
             params.utmip = utils.anonymize_ip(params.utmip)
@@ -981,7 +988,7 @@ class X10(object):
             except KeyError:
                 return char
 
-        return ''.join(map(_translate, str(value)))
+        return u''.join(map(_translate, value)).encode('utf-8', 'ignore')
 
     def __render_data_type(self, data):
         '''Given a data array for a certain type, render its string encoding.'''
